1. Make a vx.y.z tag for the next release based on CHANGELOG.md and push it to origin.
2. Use pbcopy to copy the relevant release notes from CHANGELOG.md to the clipboard.
3. Bump the patch version, commit, and push that to main, updating CHANGELOG.md with the new section.